# UniversalParser
一款通用的文本格式解析器，支持XML、JSON、YAML、HTML、XHTML等文本格式的快速解析，在方法上具有高度一致性。  
本工具的前身是 `xmltocd`，目前已更名为 `UniversalParser`。  
`xmltocd`不准备继续维护，这个库可能在未来删除掉。  

`online tutorial`：http://101.34.219.31:8001/（陆续更新中）  

# 注：
0.2.4.0 已支持JSON、和YAML。    
0.2.5.0 移除对 xmltodict 的依赖，速度更快，兼容性更好。  
0.2.5.1 支持直接对 word 的表格进行操作。  
0.2.6.0 非递归核心算法实现（已取代递归）；新增支持解析 HTML、PPT、Excel；修复一些已知 BUG。    
0.2.6.1 修复已知BUG。  
0.2.6.2 优化使用体验。  
0.2.6.3 修复删除列表节点时误删其它标签同名的节点的问题。  

=====================================  
0.2.7.0 第一个正式版本发布。   
0.2.7.1 修复现有方法的已知BUG。新增 `swap()` 方法，可用于交换任意的两个节点。  
0.2.7.2 新增两个方法：`pan_up()`、`pan_down()`，分别用于将某一节点向上/向下平移（不能跨级移动）。  
0.2.7.3 修复 `Word` 模块不可用问题。  
0.2.7.4 修复已知BUG，新增 Excel 的读操作。  


=====================================  
0.2.8.0 底层算法大幅度优化，解析速度提升近 `5万倍`，优化大部分常用方法。建议 `0.2.8.0` 之前的版本不要再使用。  
0.2.8.1 新增支持 xlsm 宏文件解析。  


## 若您有意参与本工具的开发，请直接联系：jiyangj@foxmail.com，期待您的意见。
